Specifications
==============

This section contains specifications for future Zuul development.  As
we work on implementing significant changes, these document our plans
for those changes and help us work on them collaboratively.

.. warning:: These are not authoritative documentation.  These
   features are not currently available in Zuul.  They may change
   significantly before final implementation, or may never be fully
   completed.

.. toctree::
   :maxdepth: 1

   container-build-resources
   multiple-ansible-versions
